Applications Built On Boto — boto v2.25.0

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.25.0 »

# Applications Built On Boto

Many people have taken Boto and layered on additional functionality, then shared them with the community. This is a (partial) list of applications that use Boto.

If you have an application or utility you’ve open-sourced that uses Boto & you’d like it listed here, please submit a pull request adding it!

botornado
  https://pypi.python.org/pypi/botornado An asynchronous AWS client on Tornado. This is a dirty work to move boto onto Tornado ioloop. Currently works with SQS and S3.
boto_rsync
  https://pypi.python.org/pypi/boto_rsync boto-rsync is a rough adaptation of boto’s s3put script which has been reengineered to more closely mimic rsync. Its goal is to provide a familiar rsync-like wrapper for boto’s S3 and Google Storage interfaces.
boto_utils
  https://pypi.python.org/pypi/boto_utils Command-line tools for interacting with Amazon Web Services, based on Boto. Includes utils for S3, SES & Cloudwatch.
django-storages
  https://pypi.python.org/pypi/django-storages A collection of storage backends for Django. Features the `S3BotoStorage` backend for storing media on S3.
mr.awsome
  https://pypi.python.org/pypi/mr.awsome mr.awsome is a commandline-tool (aws) to manage and control Amazon Webservice’s EC2 instances. Once configured with your AWS key, you can create, delete, monitor and ssh into instances, as well as perform scripted tasks on them (via fabfiles). Examples are adding additional, pre-configured webservers to a cluster (including updating the load balancer), performing automated software deployments and creating backups - each with just one call from the commandline.

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.25.0 »